@@ -128,8 +128,6 @@ class TlmsWmsEntDirect(models.Model):
     transaction_mode = models.CharField(max_length=50, verbose_name="成交方式", help_text="成交方式", null=True, blank=True)
     est_arrival_time = models.DateField(verbose_name="预计到港日期", help_text="预计到港日期", null=True, blank=True)
     arrival_time = models.DateField(verbose_name="到港日期", help_text="到港日期", null=True, blank=True)
-    sender = models.CharField(max_length=100, verbose_name="发货人", null=True, blank=True)
-    receiver = models.CharField(max_length=100, verbose_name="收货人", null=True, blank=True)
     # wms
     remark = models.CharField(max_length=200, verbose_name="备注", help_text="备注", null=True, blank=True)
     plan_ent_date = models.DateTimeField(verbose_name="出入库时间")
